@@ -8,14 +8,13 @@ package Template::Alloy;
 
 use strict;
 use warnings;
-use 5.006;
 use Template::Alloy::Exception;
 use Template::Alloy::Operator qw(play_operator define_operator);
 use Template::Alloy::VMethod  qw(define_vmethod $SCALAR_OPS $ITEM_OPS $ITEM_METHODS $FILTER_OPS $LIST_OPS $HASH_OPS $VOBJS);
 
 use vars qw($VERSION);
 BEGIN {
-    $VERSION            = '1.019';
+    $VERSION            = '1.021';
 };
 our $QR_PRIVATE         = qr/^[_.]/;
 our $WHILE_MAX          = 1000;
@@ -234,6 +233,7 @@ sub load_template {
             $doc->{'_perl'} = $self->load_perl($doc) if ! $doc->{'_perl'} && $self->{'COMPILE_PERL'}; # second hit
             return $doc;
         }
+        delete @$doc{qw(_tree modtime _content _line_offsets _perl _js)};
 
     ### looks like a previously cached not-found
     } elsif ($self->{'_not_found'}->{$file}) {
@@ -603,6 +603,8 @@ sub play_expr {
                 } else {
                     $ref = undef;
                 }
+            } else {
+                $ref = undef;
             }
         }
 
