@@ -177,7 +177,7 @@ register_simple, register_pair, alias_simple, alias_pair, remove_simple, remove_
 
 =head1 AUTHOR
 
-Paul Seamons <paul at seamons dot com>
+Paul Seamons <paul@seamons.com>
 
 =head1 LICENSE
 
